@@ -1,3 +1,4 @@
+#include <QtGui/QApplication>
 #include <QtGui/QGraphicsObject>
 #include "examplewidget.h"
 char a = 'c';
@@ -7,15 +8,6 @@ char ** c = &b;
 
 QDialGPS::QDialGPS(int argc, char** argv) :  QApplication(argc, argv)
  {
-    // m_location = QGeoPositionInfoSource::createDefaultSource(this);
-       // m_satellite = QGeoSatelliteInfoSource::createDefaultSource(this);
-        // Listen satellite status changes
-      //  if (m_satellite != 0) {
-      //      connect(m_satellite, SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo>&)),
-      //              this, SLOT(satellitesInViewUpdated(const QList<QGeoSatelliteInfo>&)));
-       //     connect(m_satellite, SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo>&)),
-        //            this, SLOT(satellitesInUseUpdated(const QList<QGeoSatelliteInfo>&)));
-      //  }
  qDebug("constructor started");
 angle = 99;
 x=1;
@@ -24,94 +16,64 @@ z=11111111;
 goalx=1111;
 goaly=1111;
 goalz=11111111;
-connected=false;
+setCon(false);
  qDebug("constructor ended");
-//     x=(m_location->lastKnownPosition().coordinate()).latitude();
-//     y=(m_location->lastKnownPosition().coordinate()).longitude();
-//     QObject::connect(m_location, SIGNAL(positionUpdated(const QGeoPositionInfo&)), this, SLOT(updateAngle(QGeoPositionInfo)));
- }
+}
 static void changed(LocationGPSDevice *device, gpointer pointer)
 {
  qDebug("changed");
-app.x=device->fix->latitude;
-app.y=device->fix->longitude;
+app.setCx(device->fix->latitude);
+app.setCy(device->fix->longitude);
 if(device->fix->altitude)
  {
-  app.z=device->fix->altitude;
+  app.setCz(device->fix->altitude);
  }
-if(app.goalx==1111)
+if(app.gx()==1111)
  {
-   app.goalx=app.x;
+   app.setGx(app.cx());
  }
-if(app.goaly==1111)
+if(app.gy()==1111)
  {
-   app.goaly=app.y;
+   app.setGy(app.cy());
  }
-if(app.goalz==11111111)
+if(app.gz()==11111111)
  {
-   if(!(app.z==app.goalz))
-   {
-      app.goalz=app.z;
-   }
+      app.setGz(app.cz());
  }
+ app.setPangle(QGeoCoordinate(app.cx(),app.cy()).azimuthTo(QGeoCoordinate (app.gx(),app.gy())));
+ app.setDist(0);
+ app.setAlti(0);
  qDebug("applied");
 }
  
 static void connected(LocationGPSDevice *device, gpointer pointer)
 {
     qDebug("connection starting");
-    app.connected = true;
+    app.setCon(true);
     qDebug("connection started");
 }
  
 static void disconnected(LocationGPSDevice *device, gpointer pointer)
 {
     qDebug("connection ending");
-    app.connected = false;
+    app.setCon(false);
     qDebug("connection ended");
 }
-
-double QDialGPS::gangle()
-{
- qDebug("gangle");
- angle=QGeoCoordinate(x,y).azimuthTo(QGeoCoordinate (goalx,goaly));
- qDebug(QString::number(angle).toLatin1());
- return angle;
-}
-QString QDialGPS::gext()
-{
- qDebug("gext");
- return QString::number(QGeoCoordinate(x,y).distanceTo(QGeoCoordinate (goalx,goaly)));
-}
-double QDialGPS::gx()
-{
- qDebug("gx");
- return goalx;
-}
-double QDialGPS::gy()
-{
- qDebug("gy");
- return goaly;
-}
-double QDialGPS::gz()
-{
- qDebug("gz");
- return goalz;
-}
-bool QDialGPS::con()
-{
- qDebug("con");
- return connected;
-}
 void QDialGPS::regoal()
 {
  qDebug("regoaling");
- if(connected)
-  {
-    goalx=x;
-    goaly=y;
-    goalz=z;
-  }
+if(x!=1111)
+{
+    setGx(x);
+}
+if(y!=1111)
+{
+    setGy(y);
+}
+if(z!=11111111)
+{
+    setGz(z);
+}
  qDebug("regoaled");
 }
  int main(int argc, char *argv[])
@@ -131,10 +93,11 @@ void QDialGPS::regoal()
         g_signal_connect(device, "connected", G_CALLBACK(connected), 0);
         g_signal_connect(device, "disconnected", G_CALLBACK(disconnected), 0);
     }
- 
+
     view.rootContext()->setContextProperty("qlgps", &app);
      view.setSource(QUrl("/opt/usr/bin/qtdialgps/ui.qml"));
      view.setResizeMode(QDeclarativeView::SizeRootObjectToView);
+
      qDebug("connected?");
       #if defined(Q_WS_S60) || defined(Q_WS_MAEMO)
         view.showMaximized();
@@ -142,12 +105,14 @@ void QDialGPS::regoal()
        view.setGeometry(100, 100, 800, 480);
        view.show();
      #endif
+qDebug("view shown");
+
     int ret = app.exec();
  
     if (device)
         g_object_unref(device);
     if (control)
         location_gpsd_control_stop(control);
- 
+delete &app;
     return ret;
  }
\ No newline at end of file
